function [q,me]=TessSim(N,order)
% FUNCTION fc_hypermesh.CG.TessSim: Tessallations by d-simplices
%     of the cartesian grid.
%
% USAGE
%   [q,me]=fc_hypermesh.CG.TessSim(N,order) 
% 
% INPUT
%   N : 1-by-d array. Specify the cartesian grid [0,N(1)]x...x[0,N(d)].
%
% OUTPUT
%   q : d-by-nq array with nq=(N(1)+1)x...x(N(d)+1). 
%       Contains all the points of the cartesian grid
%   me: (C_{d+order}^d)-by-nme array with nme=d!xN(1)x...xN(d).
%       Connectivity array of the triangulation.
%
%    Copyright (C) 2016-2020 F. Cuvelier
% 
  if nargin==1, order=1;end
  d=length(N);
  q=fc_hypermesh.CG.points(order*N)/order;
  beta=fc_hypermesh.CG.beta(order*N) ;
  ibase=order*(beta*fc_hypermesh.CG.points(N-1))+1;
  Nh=size(ibase,2);
  [qK,meK]=fc_hypermesh.CG.KuhnTriangulationOrder(d,order);
  nK=size(meK,1); % =(d+order)!/(d!order!)
  fd=factorial(d);
  me=zeros(nK,fd*Nh);
  Idx=fd*[0:(Nh-1)];
  for l=1:fd
    Idx=Idx+1;
    for j=1:nK
      me(j,Idx)=ibase+order*beta*qK(:,meK(j,l));
    end
  end
end

